@@ -31,7 +31,7 @@ define('PEAR_COMMAND_CHANNELS_CHANNEL_EXISTS', -500);
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.17
+ * @version    Release: 1.10.18
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 1.4.0a1
  */
@@ -558,8 +558,9 @@ configuration.',
                         $c->getName() . '" (' . $contents->getMessage() . ')');
                 }
             }
-
-            list($contents, $lastmodified) = $contents;
+            if (is_array($contents)) {
+                list($contents, $lastmodified) = $contents;
+	    }
             if (!$contents) {
                 $this->ui->outputData("Channel \"$params[0]\" is up to date");
                 return;
