@@ -10,7 +10,6 @@
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    CVS: $Id: CLI.php 308695 2011-02-25 23:40:14Z dufuz $
  * @link       http://pear.php.net/package/PEAR
  * @since      File available since Release 0.1
  */
@@ -27,7 +26,7 @@ require_once 'PEAR/Frontend.php';
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.9.3
+ * @version    Release: 1.10.18
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 0.1
  */
@@ -47,9 +46,9 @@ class PEAR_Frontend_CLI extends PEAR_Frontend
         'normal' => '',
     );
 
-    function PEAR_Frontend_CLI()
+    function __construct()
     {
-        parent::PEAR();
+        parent::__construct();
         $term = getenv('TERM'); //(cox) $_ENV is empty for me in 4.1.1
         if (function_exists('posix_isatty') && !posix_isatty(1)) {
             // output is being redirected to a file or through a pipe
@@ -358,7 +357,11 @@ class PEAR_Frontend_CLI extends PEAR_Frontend
 
     function userConfirm($prompt, $default = 'yes')
     {
-        trigger_error("PEAR_Frontend_CLI::userConfirm not yet converted", E_USER_ERROR);
+        if (PHP_VERSION_ID < 70000) {
+            trigger_error("PEAR_Frontend_CLI::userConfirm not yet converted", E_USER_ERROR);
+        } else {
+            throw new Error('PEAR_Frontend_CLI::userConfirm not yet converted');
+        }
         static $positives = array('y', 'yes', 'on', '1');
         static $negatives = array('n', 'no', 'off', '0');
         print "$this->lp$prompt [$default] : ";
@@ -748,4 +751,4 @@ class PEAR_Frontend_CLI extends PEAR_Frontend
     {
         print $text;
     }
-}
\ No newline at end of file
+}
