@@ -10,7 +10,6 @@
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    CVS: $Id: RunTest.php 309040 2011-03-08 22:46:12Z dufuz $
  * @link       http://pear.php.net/package/PEAR
  * @since      File available since Release 1.3.3
  */
@@ -38,7 +37,7 @@ putenv("PHP_PEAR_RUNTESTS=1");
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.9.3
+ * @version    Release: 1.10.18
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 1.3.3
  */
@@ -60,14 +59,11 @@ class PEAR_RunTest
     var $ini_overwrites = array(
         'output_handler=',
         'open_basedir=',
-        'safe_mode=0',
         'disable_functions=',
         'output_buffering=Off',
         'display_errors=1',
         'log_errors=0',
         'html_errors=0',
-        'track_errors=1',
-        'report_memleaks=0',
         'report_zend_debug=0',
         'docref_root=',
         'docref_ext=.html',
@@ -75,7 +71,6 @@ class PEAR_RunTest
         'error_append_string=',
         'auto_prepend_file=',
         'auto_append_file=',
-        'magic_quotes_runtime=0',
         'xdebug.default_enable=0',
         'allow_url_fopen=1',
     );
@@ -84,7 +79,7 @@ class PEAR_RunTest
      * An object that supports the PEAR_Common->log() signature, or null
      * @param PEAR_Common|null
      */
-    function PEAR_RunTest($logger = null, $options = array())
+    function __construct($logger = null, $options = array())
     {
         if (!defined('E_DEPRECATED')) {
             define('E_DEPRECATED', 0);
@@ -92,7 +87,14 @@ class PEAR_RunTest
         if (!defined('E_STRICT')) {
             define('E_STRICT', 0);
         }
-        $this->ini_overwrites[] = 'error_reporting=' . (E_ALL & ~(E_DEPRECATED | E_STRICT));
+        $excluded_error_reporting = E_DEPRECATED;
+        if (!defined('PHP_VERSION_ID') || PHP_VERSION_ID < 80400) {
+            $excluded_error_reporting |= E_STRICT;
+        }
+        $this->ini_overwrites[] = 'error_reporting=' . (E_ALL & ~$excluded_error_reporting);
+        if (!defined('PHP_VERSION_ID') || PHP_VERSION_ID < 80500) {
+            $this->ini_overwrites[] = 'report_memleaks=0';
+        }
         if (is_null($logger)) {
             require_once 'PEAR/Common.php';
             $logger = new PEAR_Common;
@@ -115,19 +117,11 @@ class PEAR_RunTest
     function system_with_timeout($commandline, $env = null, $stdin = null)
     {
         $data = '';
-        if (version_compare(phpversion(), '5.0.0', '<')) {
-            $proc = proc_open($commandline, array(
-                0 => array('pipe', 'r'),
-                1 => array('pipe', 'w'),
-                2 => array('pipe', 'w')
-                ), $pipes);
-        } else {
-            $proc = proc_open($commandline, array(
-                0 => array('pipe', 'r'),
-                1 => array('pipe', 'w'),
-                2 => array('pipe', 'w')
-                ), $pipes, null, $env, array('suppress_errors' => true));
-        }
+        $proc = proc_open($commandline, array(
+            0 => array('pipe', 'r'),
+            1 => array('pipe', 'w'),
+            2 => array('pipe', 'w')
+        ), $pipes, null, $env, array('suppress_errors' => true));
 
         if (!$proc) {
             return false;
@@ -141,7 +135,8 @@ class PEAR_RunTest
         while (true) {
             /* hide errors from interrupted syscalls */
             $r = $pipes;
-            $e = $w = null;
+            unset($r[0]);
+            $e = $w = [];
             $n = @stream_select($r, $w, $e, 60);
 
             if ($n === 0) {
@@ -231,12 +226,7 @@ class PEAR_RunTest
     function _preparePhpBin($php, $file, $ini_settings)
     {
         $file = escapeshellarg($file);
-        // This was fixed in php 5.3 and is not needed after that
-        if (OS_WINDOWS && version_compare(PHP_VERSION, '5.3', '<')) {
-            $cmd = '"'.escapeshellarg($php).' '.$ini_settings.' -f ' . $file .'"';
-        } else {
-            $cmd = $php . $ini_settings . ' -f ' . $file;
-        }
+        $cmd = $php . $ini_settings . ' -f ' . $file;
 
         return $cmd;
     }
@@ -275,10 +265,8 @@ class PEAR_RunTest
      */
     function run($file, $ini_settings = array(), $test_number = 1)
     {
-        if (isset($this->_savephp)) {
-            $this->_php = $this->_savephp;
-            unset($this->_savephp);
-        }
+        $this->_restorePHPBinary();
+
         if (empty($this->_options['cgi'])) {
             // try to see if php-cgi is in the path
             $res = $this->system_with_timeout('php-cgi -v');
@@ -340,7 +328,7 @@ class PEAR_RunTest
                 }
                 return 'SKIPPED';
             }
-            $this->_savephp = $this->_php;
+            $this->_savePHPBinary();
             $this->_php = $this->_options['cgi'];
         }
 
@@ -361,7 +349,7 @@ class PEAR_RunTest
 
         // Check if test should be skipped.
         $res  = $this->_runSkipIf($section_text, $temp_skipif, $tested, $ini_settings);
-        if (count($res) != 2) {
+        if ($res == 'SKIPPED' || count($res) != 2) {
             return $res;
         }
         $info = $res['info'];
@@ -388,13 +376,15 @@ class PEAR_RunTest
             $namespace         = '';
             $coverage_shutdown = 'coverage_shutdown';
 
+            if (
+                substr($lines[0], 0, 2) == '<?' ||
+                substr($lines[0], 0, 5) == '<?php'
+            ) {
+                unset($lines[0]);
+            }
+
+
             for ($i = 0; $i < $numLines; $i++) {
-                $lines[$i] = trim($lines[$i]);
-
-                if ($lines[$i] == '<?' || $lines[$i] == '<?php') {
-                    unset($lines[$i]);
-                }
-
                 if (isset($lines[$i]) && substr($lines[$i], 0, 9) == 'namespace') {
                     $namespace         = substr($lines[$i], 10, -1);
                     $coverage_shutdown = $namespace . '\\coverage_shutdown';
@@ -405,9 +395,9 @@ class PEAR_RunTest
                 }
             }
 
-            $text .= "\n" . 'xdebug_stop_code_coverage();' .
+            $text .= "\n    xdebug_stop_code_coverage();" .
                 "\n" . '} // end coverage_shutdown()' .
-                "\n" . 'register_shutdown_function("' . $coverage_shutdown . '");';
+                "\n\n" . 'register_shutdown_function("' . $coverage_shutdown . '");';
             $text .= "\n" . 'xdebug_start_code_coverage(XDEBUG_CC_UNUSED | XDEBUG_CC_DEAD_CODE);' . "\n";
 
             $this->save_text($temp_file, "<?php\n" . $namespace . $text  . "\n" . implode("\n", $lines));
@@ -492,8 +482,6 @@ class PEAR_RunTest
         }
         chdir($cwd); // in case the test moves us around
 
-        $this->_testCleanup($section_text, $temp_clean);
-
         /* when using CGI, strip the headers from the output */
         $output = $this->_stripHeadersCGI($output);
 
@@ -514,6 +502,9 @@ class PEAR_RunTest
                 $output .= "\n====EXPECTHEADERS FAILURE====:\n$changed";
             }
         }
+
+        $this->_testCleanup($section_text, $temp_clean);
+
         // Does the output match what is expected?
         do {
             if (isset($section_text['EXPECTF']) || isset($section_text['EXPECTREGEX'])) {
@@ -527,6 +518,7 @@ class PEAR_RunTest
                     $wanted_re = preg_quote($wanted_re, '/');
                     // Stick to basics
                     $wanted_re = str_replace("%s", ".+?", $wanted_re); //not greedy
+                    $wanted_re = str_replace("%S", ".*?", $wanted_re); //not greedy
                     $wanted_re = str_replace("%i", "[+\-]?[0-9]+", $wanted_re);
                     $wanted_re = str_replace("%d", "[0-9]+", $wanted_re);
                     $wanted_re = str_replace("%x", "[0-9a-fA-F]+", $wanted_re);
@@ -637,6 +629,11 @@ class PEAR_RunTest
         $expectf = isset($section_text['EXPECTF']) ? $wanted_re : null;
         $data = $this->generate_diff($wanted, $output, $returns, $expectf);
         $res  = $this->_writeLog($diff_filename, $data);
+        if (isset($this->_options['showdiff'])) {
+            $this->_logger->log(0, "========DIFF========");
+            $this->_logger->log(0, $data);
+            $this->_logger->log(0, "========DONE========");
+        }
         if (PEAR::isError($res)) {
             return $res;
         }
@@ -952,6 +949,8 @@ $text
     function _testCleanup($section_text, $temp_clean)
     {
         if ($section_text['CLEAN']) {
+            $this->_restorePHPBinary();
+
             // perform test cleanup
             $this->save_text($temp_clean, $section_text['CLEAN']);
             $output = $this->system_with_timeout("$this->_php $temp_clean  2>&1");
@@ -963,4 +962,18 @@ $text
             }
         }
     }
+
+    function _savePHPBinary()
+    {
+        $this->_savephp = $this->_php;
+    }
+
+    function _restorePHPBinary()
+    {
+        if (isset($this->_savephp))
+        {
+            $this->_php = $this->_savephp;
+            unset($this->_savephp);
+        }
+    }
 }
